@@ -12,11 +12,11 @@ Usage::
     ```
 """
 import sys
-from typing import IO, Any, Dict, Union
+from typing import IO, Dict, Union
 
 from botocore.response import StreamingBody
 
-if sys.version_info >= (3, 8):
+if sys.version_info >= (3, 9):
     from typing import TypedDict
 else:
     from typing_extensions import TypedDict
@@ -96,7 +96,7 @@ class InvokeEndpointInputRequestTypeDef(
 InvokeEndpointOutputTypeDef = TypedDict(
     "InvokeEndpointOutputTypeDef",
     {
-        "Body": bytes,
+        "Body": StreamingBody,
         "ContentType": str,
         "InvokedProductionVariant": str,
         "CustomAttributes": str,
@@ -110,7 +110,7 @@ ResponseMetadataTypeDef = TypedDict(
         "RequestId": str,
         "HostId": str,
         "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, Any],
+        "HTTPHeaders": Dict[str, str],
         "RetryAttempts": int,
     },
 )
